@@ -1,3 +1,4 @@
+# type: ignore
 """Base class for central moments calculations."""
 
 
@@ -24,11 +25,11 @@ from numpy.typing import ArrayLike, DTypeLike
 
 from . import convert
 from ._docstrings import docfiller_shared
+from ._formatting import repr_html
 from ._typing import Moments, T_Array, T_CentralMoments
 from .cached_decorators import gcached
 from .options import DOC_SUB
 from .pushers import factory_pushers
-from .resample import randsamp_freq, resample_data
 
 # * TODO Main
 # TODO: Total rework is called for to handle typing correctly.
@@ -42,24 +43,27 @@ def _get_metaclass():
 
 
 class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
-    r"""Wrapper to calculate central moments.
+    r"""
+    Wrapper to calculate central moments.
 
     Base data has the form
 
     .. math::
 
         data[..., i, j] = \begin{cases}
-            \text{weight} & i = j = 0 \\
+             \text{weight} & i = j = 0 \\
             \langle x \rangle & i = 1, j = 0 \\
-            \langle (x - \langle x \rangle^i) (y - \langle y \rangle^j) \rangle & i + j > 0
+            \langle (x - \langle x \rangle^i) (y - \langle y \rangle^j)
+            \rangle & i + j > 0
         \end{cases}
 
     Parameters
     ----------
-    data : xr.DataArray / np.ndarray
+    data : DataArray or ndarray
         Moment collection array.
     mom_ndim : {1, 2}
         Number of dimensions for moment part of `data`.
+
         * 1 : central moments of single variable
         * 2 : central comoments of two variables
 
@@ -79,7 +83,6 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         return super().__new__(cls)  # , data=data, mom_ndim=mom_ndim)
 
     def __init__(self, data: T_Array, mom_ndim: Literal[1, 2] = 1) -> None:
-
         self._data = cast(np.ndarray, data)
         self._data_flat = self._data
 
@@ -88,12 +91,14 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
     @property
     def data(self) -> np.ndarray:
-        """Accessor to numpy array underlying data.
+        """
+        Accessor to numpy array underlying data.
 
         By convention data has the following meaning for the moments indexes
 
         * `data[...,i=0,j=0]`, weights
-        * `data[...,i=1,j=0]]`, if only one moment index is one and all others zero, then this is the average value of the variable with unit index.
+        * `data[...,i=1,j=0]]`, if only one moment index is one and all others zero,
+          then this is the average value of the variable with unit index.
         * all other cases, the central moments `<(x0-<x0>)**i0 * (x1 - <x1>)**i1 * ...>`
 
         """
@@ -123,7 +128,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
     @property
     def mom_ndim(self) -> Literal[1, 2]:
-        """Length of moments.
+        """
+        Length of moments.
 
         if `mom_ndim` == 1, then single variable
         moments if `mom_ndim` == 2, then co-moments.
@@ -144,7 +150,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
     @property
     def val_shape(self) -> tuple[int, ...]:
-        """Shape of values dimensions.
+        """
+        Shape of values dimensions.
 
         That is shape less moments dimensions.
         """
@@ -195,6 +202,9 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         s = f"<{name}(val_shape={self.val_shape}, mom={self.mom})>\n"
         return s + repr(self.values)
 
+    def _repr_html_(self):
+        return repr_html(self)
+
     def __array__(self, dtype: DTypeLike | None = None) -> np.ndarray:
         """Used by np.array(self)."""  # noqa D401
         return np.asarray(self.data, dtype=dtype)
@@ -240,11 +250,13 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         pass
 
     def zeros_like(self: T_CentralMoments) -> T_CentralMoments:
-        """Create new empty object like self.
+        """
+        Create new empty object like self.
 
         Returns
         -------
-        output : same as object
+        output : object
+            Same type as calling class.
             Object with same attributes as caller, but with data set to zero.
 
         See Also
@@ -255,7 +267,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         return self.new_like()
 
     def copy(self: T_CentralMoments, **copy_kws) -> T_CentralMoments:
-        """Create a new object with copy of data.
+        """
+        Create a new object with copy of data.
 
         Parameters
         ----------
@@ -264,7 +277,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        output : same as object
+        output : object
+            Same type as calling class.
             Object with same attributes as caller, but with new underlying data.
 
 
@@ -331,7 +345,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         return cast(T_Array, x)
 
     def cmom(self) -> T_Array:
-        r"""Central moments.
+        r"""
+        Central moments.
 
         Strict central moments of the form
 
@@ -381,7 +396,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         return self._wrap_like(out)
 
     def rmom(self) -> T_Array:
-        r"""Raw moments.
+        r"""
+        Raw moments.
 
         .. math::
             \text{rmom[..., n, m]} = \langle x^n y^m \rangle
@@ -401,7 +417,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
     # ** pushing routines
     ###########################################################################
     def fill(self: T_CentralMoments, value: Any = 0) -> T_CentralMoments:
-        """Fill data with value.
+        """
+        Fill data with value.
 
         Parameters
         ----------
@@ -410,18 +427,21 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        self : same as object
+        self : object
+            Same type as calling class.
             Same object as caller with data filled with `values`
         """
         self._data.fill(value)
         return self
 
     def zero(self: T_CentralMoments) -> T_CentralMoments:
-        """Zero out underlying data.
+        """
+        Zero out underlying data.
 
         Returns
         -------
-        self : same as object
+        self : object
+            Same type as calling class.
             Same object with data filled with zeros.
 
         See Also
@@ -676,24 +696,29 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         **kwargs,
     ) -> T_CentralMoments:
         """
-        Apply `func_or_method` to underlying data and wrap results in `xCentralMoments` object.
+        Apply `func_or_method` to underlying data and wrap results in
+        class:`cmomy.xCentralMoments` object.
 
-        This is useful for calling any not implemented methods on ndarray or DataArray data.
+        This is useful for calling any not implemented methods on :class:`numpy.ndarray` or
+        :class:`xarray.DataArray` data.
 
         Parameters
         ----------
         func_or_method : str or callable
-            If callable, then apply ``values = func_or_method(self.values, *args, **kwargs)``.
-            If string is passed, then ``values = getattr(self.values, func_or_method)(*args, **kwargs)``.
-        _order : bool, default = True
+            If callable, then apply ``values = func_or_method(self.values,
+            *args, **kwargs)``. If string is passed, then ``values =
+            getattr(self.values, func_or_method)(*args, **kwargs)``.
+        _order : bool, default=True
             If True, reorder the data such that ``mom_dims`` are last.
-        _copy : bool, default = False
+        _copy : bool, default=False
             If True, copy the resulting data.  Otherwise, try to use a view.
             This is passed as ``copy=_copy`` to :meth:`from_data`.
         _verify: bool, default=False
-            If True, ensure underlying data is contiguous.  Passed as ``verify=_verify`` to :meth:`from_data`
-        _check_mom: bool, default = True
-            If True, check the resulting object has the same moment shape as the current object.
+            If True, ensure underlying data is contiguous. Passed as
+            ``verify=_verify`` to :meth:`from_data`
+        _check_mom: bool, default=True
+            If True, check the resulting object has the same moment shape as the
+            current object.
         _kws : Mapping, optional
             Extra arguments to :meth:`from_data`.
         *args
@@ -703,13 +728,15 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        output : xCentralMoments
-            New :class:`xCentralMoments` object after `func_or_method` is applies to `self.values`
+        output : :class:`cmomy.xCentralMoments`
+            New :class:`cmomy.xCentralMoments` object after `func_or_method` is
+            applies to `self.values`
 
 
         Notes
         -----
-        Use leading underscore for `_order`, `_copy` to avoid name possible name clashes.
+        Use leading underscore for `_order`, `_copy` to avoid name possible name
+        clashes.
 
 
         See Also
@@ -751,65 +778,6 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
             raise ValueError(message)
 
     # * Universal reducers
-    @docfiller_shared
-    def resample_and_reduce(
-        self: T_CentralMoments,
-        freq: np.ndarray | None = None,
-        indices: np.ndarray | None = None,
-        nrep: None = None,
-        axis: int | None = None,
-        parallel: bool = True,
-        resample_kws: Mapping | None = None,
-        full_output: bool = False,
-        **kws,
-    ) -> T_CentralMoments | tuple[T_CentralMoments, np.ndarray]:
-        """
-        Bootstrap resample and reduce.
-
-        Parameters
-        ----------
-        {freq}
-        {indices}
-        {nrep}
-        {axis}
-        parallel : bool, default=True
-            flags to `numba.njit`
-        {resample_kws}
-        {full_output}
-        **kws
-            Extra key-word arguments to :meth:`from_data`
-
-        Returns
-        -------
-        output : instance of calling class
-            Note that new object will have val_shape = (nrep,) + val_shape[:axis] + val_shape[axis+1:]
-
-        See Also
-        --------
-        :meth:`resample`
-        :meth:`reduce`
-        ~resample.randsamp_freq
-        ~resample.freq_to_indices
-        ~resample.indices_to_freq
-        ~resample.resample_data
-        """
-        self._raise_if_scalar()
-        axis = self._wrap_axis(axis, **kws)
-        if resample_kws is None:
-            resample_kws = {}
-
-        freq = randsamp_freq(
-            nrep=nrep, indices=indices, freq=freq, size=self.val_shape[axis], check=True
-        )
-        data = resample_data(
-            self.data, freq, mom=self.mom, axis=axis, parallel=parallel, **resample_kws
-        )
-        out = type(self).from_data(data, mom_ndim=self.mom_ndim, copy=False, **kws)
-
-        if full_output:
-            return out, freq
-        else:
-            return out
 
     @docfiller_shared
     def resample(
@@ -833,7 +801,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        output : instance of calling class
+        output : object
+            Instance of calling class
             The new object will have shape
             `(nrep, ndat, ...) + self.shape[:axis] + self.shape[axis+1:]`
 
@@ -862,84 +831,6 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
             **kws,
         )
 
-    @docfiller_shared
-    def reduce(
-        self: T_CentralMoments, axis: int | None = None, **kws
-    ) -> T_CentralMoments:
-        """
-        Create new object reduce along axis.
-
-        Parameters
-        ----------
-        {axis}
-        **kws
-            Extra parameters to :meth:`from_data`
-
-        """
-        self._raise_if_scalar()
-        axis = self._wrap_axis(axis, **kws)
-        return type(self).from_datas(
-            self.values, mom_ndim=self.mom_ndim, axis=axis, **kws
-        )
-
-    @docfiller_shared
-    def block(
-        self: T_CentralMoments,
-        block_size: int | None = None,
-        axis: int | None = None,
-        **kws,
-    ) -> T_CentralMoments:
-        """
-        Block average reduction.
-
-        Parameters
-        ----------
-        block_size : int
-            number of consecutive records to combine
-        {axis}
-        **kws
-            Extra key word arguments to :meth:`from_datas` method
-
-        Returns
-        -------
-        output : new instance of calling class
-            Shape of output will be
-            `(nblock,) + self.shape[:axis] + self.shape[axis+1:]`.
-
-        Notes
-        -----
-        The block averaged `axis` will be moved to the front of the output data.
-
-        See Also
-        --------
-        reshape
-        moveaxis
-        reduce
-        """
-
-        self._raise_if_scalar()
-
-        axis = self._wrap_axis(axis, **kws)
-        data = self.data
-
-        # move axis to first
-        if axis != 0:
-            data = np.moveaxis(data, axis, 0)
-
-        n = data.shape[0]
-
-        if block_size is None:
-            block_size = n
-            nblock = 1
-
-        else:
-            nblock = n // block_size
-
-        datas = data[: (nblock * block_size), ...].reshape(
-            (nblock, block_size) + data.shape[1:]
-        )
-        return type(self).from_datas(datas=datas, mom_ndim=self.mom_ndim, axis=1, **kws)
-
     ###########################################################################
     # ** Operators
     ###########################################################################
@@ -953,6 +844,7 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         self: T_CentralMoments,
         b: T_CentralMoments,
     ) -> T_CentralMoments:  # noqa D105
+        """Self adder."""
         self._check_other(b)
         # self.push_data(b.data)
         # return self
@@ -1018,7 +910,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
     def _check_mom(
         cls, moments: Moments, mom_ndim: int, shape: tuple[int, ...] | None = None
     ) -> tuple[int] | tuple[int, int]:  # type: ignore
-        """Check moments for correct shape.
+        """
+        Check moments for correct shape.
 
         If moments is None, infer from
         shape[-mom_ndim:] if integer, convert to tuple.
@@ -1028,7 +921,7 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
             if shape is not None:
                 if mom_ndim is None:
                     raise ValueError(
-                        "must speficy either moments or shape and mom_ndim"
+                        "must specify either moments or shape and mom_ndim"
                     )
                 moments = tuple(x - 1 for x in shape[-mom_ndim:])
             else:
@@ -1173,7 +1066,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        out : caller class instance
+        out : object
+            Same type as calling class.
 
         """
 
@@ -1213,7 +1107,7 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         See Also
         --------
-        CentralMoments.from_data
+        cmomy.CentralMoments.from_data
         """
 
     @classmethod
@@ -1301,17 +1195,18 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
 
         Returns
         -------
-        out : instance of calling class
+        out : object
+            Instance of calling class
         freq : ndarray, optional
             If `full_output` is True, also return `freq` array
 
 
         See Also
         --------
-        ~resample.resample_vals
-        ~resample.randsamp_freq
-        ~resample.freq_to_indices
-        ~resample.indices_to_freq
+        cmomy.resample.resample_vals
+        cmomy.resample.randsamp_freq
+        cmomy.resample.freq_to_indices
+        cmomy.resample.indices_to_freq
         """
 
     @classmethod
@@ -1350,8 +1245,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         --------
         to_raw
         rmom
-        ~convert.to_central_moments
-        ~convert.to_central_comoments
+        ~cmomy.convert.to_central_moments
+        ~cmomy.convert.to_central_comoments
 
         Notes
         -----
@@ -1397,8 +1292,8 @@ class CentralMomentsABC(Generic[T_Array], metaclass=_get_metaclass()):
         --------
         from_raw
         from_datas
-        ~convert.to_central_moments
-        ~convert.to_central_comoments
+        ~cmomy.convert.to_central_moments  : convert raw to central moments
+        ~cmomy.convert.to_central_comoments : convert raw to central comoments
 
         Notes
         -----
