@@ -1,4 +1,5 @@
 # Type: ignore
+
 """Thin wrapper around central routines with xarray support."""
 
 
@@ -101,7 +102,6 @@ def _xcentral_moments(
     last: bool = True,
     mom_dims: MomDims | None = None,
 ):  # -> xr.DataArray:
-
     x = vals
     assert isinstance(x, xr.DataArray)
 
@@ -219,11 +219,12 @@ def xcentral_moments(
     mom_dims: MomDims | None = None,
     broadcast: bool = False,
 ) -> xr.DataArray:
-    """Calculate central mom along axis.
+    """
+    Calculate central mom along axis.
 
     Parameters
     ----------
-    x : xarray.DataArray or tuple of xarray.Datarray
+    x : DataArray or tuple of DataArray
         input data
     {mom}
     w : array-like, optional
@@ -241,7 +242,7 @@ def xcentral_moments(
 
     Returns
     -------
-    output : xr.DataArray of moments
+    output : DataArray
         array of shape shape + (mom,) or (mom,) + shape depending on
         value of `last`, where `shape` is the shape of `x` with axis removed,
         i.e., shape=x.shape[:axis] + x.shape[axis+1:]. Assuming `last is True`,
@@ -264,7 +265,8 @@ def xcentral_moments(
 
 # * xCentralMoments
 class xCentralMoments(CentralMomentsABC[xr.DataArray]):
-    """Wrap cmomy.CentralMoments with xarray.
+    """
+    Wrap cmomy.CentralMoments with xarray.
 
     Parameters
     ----------
@@ -274,7 +276,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     Notes
     -----
-    Most methods are wrapped to accept xarray.DataArray object.
+    Most methods are wrapped to accept :class:`xarray.DataArray` object.
     """
 
     __slots__ = "_xdata"
@@ -284,7 +286,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         return super().__new__(cls, data=data, mom_ndim=mom_ndim)
 
     def __init__(self, data: xr.DataArray, mom_ndim: Literal[1, 2] = 1) -> None:
-
         if not isinstance(data, xr.DataArray):
             raise ValueError(
                 "data must be a xarray.DataArray. "
@@ -310,7 +311,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         if any(m <= 0 for m in self.mom):
             raise ValueError("moments must be positive")
 
-    # ** xarray attriburtes
+    # ** xarray attributes
     @property
     def values(self):
         """Underlying data."""
@@ -470,7 +471,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         _kws: Mapping | None = None,
         **dimensions_kwargs,
     ) -> xCentralMoments:
-        """Stack dimensions.
+        """
+        Stack dimensions.
 
         Returns
         -------
@@ -554,7 +556,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         _check_mom=True,
         _kws=None,
     ) -> xCentralMoments:
-        """Unstack dimensions.
+        """
+        Unstack dimensions.
 
         Returns
         -------
@@ -592,7 +595,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         _kws=None,
         **indexers_kws,
     ) -> xCentralMoments:
-        """Select subset of data.
+        """
+        Select subset of data.
 
         Returns
         -------
@@ -682,7 +686,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         _kws: None = None,
         **indexers_kws,
     ) -> xCentralMoments:
-        """Select subset of data by position.
+        """
+        Select subset of data by position.
 
         Returns
         -------
@@ -730,7 +735,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         See Also
         --------
         pipe
-        DataArray.transpose
         xarray.DataArray.transpose
         """
         # make sure dims are last
@@ -761,7 +765,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
     @gcached()
     def centralmoments_view(self):
-        """Create CentralMoments view.
+        """
+        Create CentralMoments view.
 
         This object has the same underlying data as `self`, but no
         DataArray attributes.  Useful for some function calls.
@@ -827,7 +832,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         template=None,
         **kwargs,
     ):
-
         method = getattr(CentralMoments, _method_name)
 
         return method(*args, **kwargs).to_xcentralmoments(
@@ -857,9 +861,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         | tuple[float, xr.DataArray]
         | float
     ):
-
         if isinstance(target, str):
-
             # if dim is not None:
             #     if isinstance(dim, int):
             #         dim = x.dims[dim]
@@ -963,7 +965,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         shape_flat: tuple[int, ...] | None = None,
     ) -> Any:
         if isinstance(x, xr.DataArray) or isinstance(target, xr.DataArray):
-
             return self._xverify_value(
                 x,
                 target=target,
@@ -1115,7 +1116,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         self, axis: int | str, default: int = 0, ndim: None = None, **kws
     ) -> int:
         if isinstance(axis, str):
-            raise ValueError("shouldnt get string axis here")
+            raise ValueError("shouldn't get string axis here")
         else:
             return super()._wrap_axis(axis=axis, default=default, ndim=ndim)
 
@@ -1446,8 +1447,8 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
         Parameters
         ----------
-        datas : ndarray or xr.DataArray
-            If pass in an xr.DataArray, use it's attributes in new object.
+        datas : ndarray or DataArray
+            If pass in a DataArray, use it's attributes in new object.
             If ndarray, use `dim`, `attrs`, etc, to wrap resulting data.
         {dim}
         {xr_params}
@@ -1460,7 +1461,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
         Notes
         -----
-        If pass in :class:`DataArray`, then dims, etc, are ignored.
+        If pass in :class:`xarray.DataArray`, then dims, etc, are ignored.
         Note that here, `dims` does not include the dimension reduced over.
         The dimensions are applied after the fact.
 
@@ -1583,7 +1584,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
             )
 
         else:
-
             new = cls._wrap_centralmoments_method(
                 "from_raw",
                 raw=raw,
@@ -1642,7 +1642,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         """
 
         if isinstance(raws, xr.DataArray):
-
             return cls.from_raw(
                 raw=raws,
                 mom=mom,
@@ -1702,7 +1701,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
 
         Parameters
         ----------
-        x : array, tuple of arrays, DataArray, or tuple of DataArray
+        x : array, tuple of array, DataArray, or tuple of DataArray
             For moments, `x=x0`.  For comoments, `x=(x0, x1)`.
             If pass DataArray, inherit attributes from `x0`.  If pass
             ndarray, use `dims`, `attrs`, etc to wrap final result
@@ -1758,7 +1757,6 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
             ).push_vals(x=x, dim=dim, w=w, broadcast=broadcast)
 
         else:
-
             new = cls._wrap_centralmoments_method(
                 "from_vals",
                 dim=dim,
@@ -1814,7 +1812,7 @@ class xCentralMoments(CentralMomentsABC[xr.DataArray]):
         """
         Parameters
         ----------
-        x : array, tuple of arrays, DataArray, or tuple of DataArray
+        x : array, tuple of array, DataArray, or tuple of DataArray
             For moments, `x=x0`.  For comoments, `x=(x0, x1)`.
             If pass DataArray, inherit attributes from `x0`.  If pass
             ndarray, use `dims`, `attrs`, etc to wrap final result
@@ -2130,7 +2128,7 @@ def _optional_wrap_data(
 
             dims_total = dims + mom_dims
         else:
-            raise ValueError("bad dims {}, moment_dims {}".format(dims, mom_dims))
+            raise ValueError(f"bad dims {dims}, moment_dims {mom_dims}")
 
         # xarray object
         data = xr.DataArray(
